@@ -1,11 +1,101 @@
 import re
 import itertools
 import collections
+from termcolor import colored
 
 import attr
 from csvw import dsv
 
-from pygrambank.srctok import iter_ayps
+from pygrambank.bib import iter_authoryearpages, mismatch_is_fatal
+
+
+def check_feature_dependencies(rows):
+    values = {
+        r.Feature_ID: r
+        for r in rows
+        if r.Feature_ID and r.Value}
+
+    def _value(feat):
+        row = values.get(feat)
+        return row.Value if row else None
+
+    def _comment(feat):   # pragma: nocover
+        row = values.get(feat)
+        return row.Comment if row else None
+
+    def _require_comment(feat, reason):
+        if not _comment(feat):
+            errors.append('{} must have a comment if {}'.format(feat, reason))
+
+    errors = []
+
+    if (_value('GB408')
+        == _value('GB409')
+        == _value('GB410')
+        == '0'
+    ):
+        errors.append("GB408, GB409, and GB410 can't all be 0")  # pragma: nocover
+
+    if (_value('GB131')
+        == _value('GB132')
+        == _value('GB133')
+        == '0'
+    ):
+        errors.append("GB131, GB132, and GB133 can't all be 0")  # pragma: nocover
+
+    if (_value('GB083')
+        == _value('GB084')
+        == _value('GB121')
+        == _value('GB521')
+        == '0'
+        and _value('GB309') == '1'
+    ):
+        errors.append(
+            "GB309 can't be 1 if GB083, GB084, GB121 and GB521 are all 0")  # pragma: nocover
+
+    if (_value('GB333')
+        == _value('GB334')
+        == _value('GB335')
+        == _value('GB336')
+        == '0'
+    ):
+        reason = 'GB333, GB334, GB335, and GB336 are all 0'
+        for feat in ('GB333', 'GB334', 'GB335', 'GB336'):  # pragma: nocover
+            _require_comment(feat, reason)
+
+    for feat in (
+        'GB026', 'GB303', 'GB320', 'GB166', 'GB197', 'GB129', 'GB285', 'GB336',
+        'GB260', 'GB165', 'GB319'
+    ):
+        if _value(feat) == '1':
+            _require_comment(feat, reason='it is coded 1')  # pragma: nocover
+
+    if (_value('GB265')
+        == _value('GB266')
+        == _value('GB273')
+        == 0
+    ):
+        reason = 'GB265, GB266, and GB273 are all 0'
+        _require_comment('GB265', reason)
+        _require_comment('GB266', reason)
+        _require_comment('GB273', reason)
+
+    if (_value('GB072')
+        == _value('GB073')
+        == _value('GB074')
+        == _value('GB075')
+        == 0
+    ):
+        reason = 'GB072, GB073, GB074, and GB075 are all 0'
+        _require_comment('GB074', reason)
+        _require_comment('GB075', reason)
+
+    if _value('GB155') == 1 and _value('GB113') == 0:
+        reason = 'GB155 is 1 and GB113 is 0'
+        _require_comment('GB155', reason)
+        _require_comment('GB113', reason)
+
+    return errors
 
 
 @attr.s
@@ -44,7 +134,15 @@ class Row:
 
     @property
     def sources(self):
-        return [Source(*ayp) for ayp in iter_ayps(self.Source)]
+        return [Source(*ayp) for ayp in iter_authoryearpages(self.Source)]
+
+    def has_valid_source(self):
+        """Return True if row has at least one matched source."""
+        sources = self.Source
+        source_string = self.Source_comment
+        return (
+            isinstance(sources, list)
+            and (bool(sources) or not mismatch_is_fatal(source_string)))
 
 
 class Sheet(object):
@@ -156,9 +254,15 @@ class Sheet(object):
                 log('source given, but no value', lineno=lineno, level='WARNING', row_=row)
             res = False
         if row['Comment']:
-            if re.search('check', row['Comment'].lower()):
-                if log:  # pragma: no cover
-                    log('comment contains string "check"', lineno=lineno, level='WARNING', row_=row)
+            if (log is not None
+                and 'check' in row['Comment'].lower()
+                and 'HG' not in row['Comment']
+                and 'checked by coder' not in row['Comment'].lower()
+                and 'check by coder' not in row['Comment'].lower()
+                and 'wrong import' not in row['Comment'].lower()
+                and 'checked by GB coder' not in row['Comment'].lower()
+            ):
+                log('comment contains string "check"', lineno=lineno, level='WARNING', row_=row)
             if not row['Value']:
                 if log:
                     log('comment given, but no value', lineno=lineno, level='WARNING', row_=row)
@@ -178,7 +282,7 @@ class Sheet(object):
                 "{}".format(lineno if lineno != -1 else '?'),
                 row_['Feature_ID'] if row_ else '',
                 msg]
-            print('\t'.join(msg))
+            print(colored('\t'.join(msg), color='red'))
             if report is not None:
                 report.append(msg)
 
@@ -204,13 +308,17 @@ class Sheet(object):
                             lineno=line,
                             level='WARNING')
 
-        res, nvalid, features = [], 0, set()
+        res, nvalid, features, comments = [], 0, set(), 0
         for line, row in enumerate(self.iterrows(), 2):  # +2 to get line number correct
             if self.valid_row(row, api, lineno=line, log=log, features=features):
                 nvalid += 1
+                comments += 1 if row['Comment'] else 0
             features.add(row['Feature_ID'])
             res.append(row)
 
+        if comments < 25:
+            log('Less than 25 datapoints have comments', level='WARNING')
+
         try:
             for gbid, rows in itertools.groupby(
                 sorted(res, key=lambda r: r['Feature_ID']), lambda r: r['Feature_ID']
@@ -228,6 +336,10 @@ class Sheet(object):
                     break
             print(self.path)
             raise
+
+        for msg in check_feature_dependencies(self.iter_row_objects(api)):
+            log(msg)  # pragma: nocover
+
         return nvalid
 
     def itervalues(self, api):
